@charset "utf-8";

/*
Hive Omnix System
Copyright (c) 2008-2022 Hive Solutions Lda.

This file is part of Hive Omnix System.

Hive Omnix System is free software: you can redistribute it and/or modify
it under the terms of the Apache License as published by the Apache
Foundation, either version 2.0 of the License, or (at your option) any
later version.

Hive Omnix System is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
Apache License for more details.

You should have received a copy of the Apache License along with
Hive Omnix System. If not, see <http://www.apache.org/licenses/>.
*/

/*
__author__    = João Magalhães <joamag@hive.pt>
__version__   = 1.0.0
__revision__  = $LastChangedRevision$
__date__      = $LastChangedDate$
__copyright__ = Copyright (c) 2008-2022 Hive Solutions Lda.
__license__   = Apache License, Version 2.0
*/

.table.table-report {
    font-size: 16px;
}

.table.table-report td {
    font-size: 16px;
}

.table.table-report thead tr th {
    border-bottom: 1px solid #e6e6e6;
    padding: 8px 14px 8px 14px;
}

.table.table-report tbody tr td {
    border-bottom: 1px solid #e6e6e6;
    padding: 10px 14px 10px 14px;
}

.table-report tbody tr:hover {
    background-color: #f6f6f6;
}

.table.table.table-resume {
    margin: 32px 0px 32px 0px;
}

.table.table.table-resume td {
    line-height: 28px;
    width: 50%;
}

.table.table-resume .value {
    font-size: 24px;
    padding-left: 20px;
    padding-right: 20px;
}

.table.table-resume.three td {
    width: 33.33%;
}

.up {
    background: transparent url(../images/up.png) no-repeat right center;
}

.down {
    background: transparent url(../images/down.png) no-repeat right center;
}

.equal {
    background: transparent url(../images/equal.png) no-repeat right center;
}

.green {
    color: #39b549;
}

.red {
    color: #ec1c23;
}

.yellow {
    color: #fdc13c;
}

.button.login {
    background: transparent url(../images/login.png) no-repeat left 0px;
    border-bottom: none;
    display: inline-block;
    height: 38px;
    padding-bottom: 0px;
    width: 204px;
}

.button.login:hover {
    background-position: left -38px;
}

.button.login.click {
    background-position: left -76px;
}

.button.login.disabled {
    background-position: left -114px;
}

.preview-panel {
    animation: fade-into-drop 0.25s cubic-bezier(0.645, 0.045, 0.355, 1.0);
    -o-animation: fade-into-drop 0.25s cubic-bezier(0.645, 0.045, 0.355, 1.0);
    -ms-animation: fade-into-drop 0.25s cubic-bezier(0.645, 0.045, 0.355, 1.0);
    -moz-animation: fade-into-drop 0.25s cubic-bezier(0.645, 0.045, 0.355, 1.0);
    -khtml-animation: fade-into-drop 0.25s cubic-bezier(0.645, 0.045, 0.355, 1.0);
    -webkit-animation: fade-into-drop 0.25s cubic-bezier(0.645, 0.045, 0.355, 1.0);
}

.preview-panel > .media-target {
    margin: 0px 0px 14px 0px;
}

.preview-panel > .media-target > .image-container {
    display: inline-block;
    margin: 12px 12px 12px 12px;
    max-width: 516px;
    text-align: center;
}

.preview-panel > .media-target > .image-container > a {
    border-bottom: none;
    padding-bottom: 0px;
}

.preview-panel > .media-target > .image-container > a > img {
    max-width: 540px;
}

.preview-panel > .media-target > .image-container > a > h2 {
    font-size: 14px;
    margin: 4px 0px 4px 0px;
}

.preview-panel > .media-target > .image-container > a > h3 {
    font-size: 12px;
    margin: 0px 0px 0px 0px;
}

.media-image {
    max-width: 620px;
}

body textarea.text-json {
    font-family: Consolas, Monaco, "Andale Mono", monospace;
    font-size: 12px;
    font-style: normal;
    font-weight: normal;
    line-height: 16px;
}
