{% extends "email/layout.en_us.html.tpl" %}
{% block title %}Happy Birthday{% endblock %}
{% block content %}
    <p>
        The management team wishes you an happy birthday!
    </p>
{% endblock %}
